@@ -273,7 +273,7 @@ class KiwoomOpenApiTrEventHandler(BaseKiwoomOpenApiEventHandler):
                 response.listen_response.single_data.names.extend(self._single_names) # pylint: disable=no-member
                 response.listen_response.single_data.values.extend(values) # pylint: disable=no-member
 
-            if len(self._multi_names) > 0 and repeat_cnt > 0:
+            if repeat_cnt > 0 and len(self._multi_names) > 0:
                 rows = [[self.control.GetCommData(trcode, recordname, i, name).strip() for name in self._multi_names] for i in range(repeat_cnt)]
                 response.listen_response.multi_data.names.extend(self._multi_names) # pylint: disable=no-member
                 for row in rows:
@@ -379,7 +379,7 @@ class KiwoomOpenApiOrderEventHandler(BaseKiwoomOpenApiEventHandler):
                 response.listen_response.single_data.names.extend(self._single_names) # pylint: disable=no-member
                 response.listen_response.single_data.values.extend(values) # pylint: disable=no-member
 
-            if len(self._multi_names) > 0 and repeat_cnt > 0:
+            if repeat_cnt > 0 and len(self._multi_names) > 0:
                 rows = [[self.control.GetCommData(trcode, recordname, i, name).strip() for name in self._multi_names] for i in range(repeat_cnt)]
                 response.listen_response.multi_data.names.extend(self._multi_names) # pylint: disable=no-member
                 for row in rows:
