@@ -1,7 +1,7 @@
 import logging
 import threading
 
-class KiwoomOpenApiSignalConnector(object):
+class KiwoomOpenApiSignalConnector:
 
     def __init__(self, name=None):
         self._name = name
